Package 'kwb.kuras'

Title: Interface to KURAS database
Description: Interface to KURAS database.
Authors: Hauke Sonnenberg [aut, cre] (ORCID: <https://orcid.org/0000-0001-9134-2871>), Michael Rustler [ctb] (ORCID: <https://orcid.org/0000-0003-0647-7726>), KURAS [fnd], Kompetenzzentrum Wasser Berlin gGmbH (KWB) [cph]
Maintainer: Hauke Sonnenberg <[email protected]>
License: MIT + file LICENSE
Version: 0.2.0
Built: 2026-05-02 16:07:56 UTC
Source: https://github.com/KWB-R/kwb.kuras

Help Index


Generate Sample Times From Flaschenbericht

Description

Generate equidistant sample times from the informatin given in the "Flaschenbericht"

Usage

generateSampleTimesFromFlaschenbericht(
  content,
  text.success = "SUCCESS",
  text.failure = "FAILURE"
)

Arguments

content

data frame with columns timeFrom, timeTo, pnSoll, pnIst,

text.success

text to be put in output column result in case of success

text.failure

text to be put in output column result in case of failure


Read KURAS Sampler File by Name

Description

Read KURAS Sampler File by Name

Usage

readKurasSamplerFileByName(samplerFile, bottlesToConsider = NA)

Arguments

samplerFile

path to file written by autosampler

bottlesToConsider

arguments passed to generateSampleTimesFromFlaschenbericht


Read KURAS Sampler File by Name

Description

Read file generated by KURAS_convertAutosamplerFiles_RBFAB.R from "_flaschenbericht" file

Usage

readKurasSamplerFileByName.R(samplerFile)

Arguments

samplerFile

path to file written by autosampler